"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.processApiError = exports.errorsAllFromValidation = exports.handleError = void 0;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _ui = require("../actions/ui");

var _alerts = require("../actions/alerts");

var _quizCommon = require("@instructure/quiz-common");

var _flatten = _interopRequireDefault(require("lodash/flatten"));

var _formatMessage = _interopRequireDefault(require("@instructure/quiz-i18n/lib/format-message"));

var handleError = function handleError(dispatch, errorMessage) {
  return function (error) {
    if (error.response && [404, 401].includes(error.response.status)) {
      // need a timeout so focus is not stolen by
      // other callbacks after the alert opens
      setTimeout(function () {
        dispatch((0, _ui.set)(_quizCommon.TRAY_ALERT_OPEN, true));
      }, 500);
    } else if (errorMessage) {
      dispatch((0, _alerts.addError)(errorMessage));
    } else if (error.response && error.response.status) {
      dispatch((0, _alerts.addError)((0, _formatMessage.default)('Sorry, there was a {status} Error.', {
        status: error.response.status
      })));
    } else {
      dispatch((0, _alerts.addError)((0, _formatMessage.default)('Sorry, there was an error.')));
    }
  };
}; // ==============================
// ==============================
//  API INPUT VALIDATION HELPERS
// ==============================
// ==============================


exports.handleError = handleError;

var validationTextForError = function validationTextForError(errorType) {
  if (errorType === 'regexp') {
    return (0, _formatMessage.default)('Invalid Regular Expression');
  }

  return (0, _formatMessage.default)('Unknown validation error');
};

var errorsAllFromValidation = function errorsAllFromValidation(errors) {
  var errorArray = (0, _flatten.default)(Object.values(errors)); // All api errors are just part of input validation flow
  // Don't show the error banner, validation feedback should be shown
  // at input level

  return errorArray.every(function (error) {
    return error.validation_error;
  });
};

exports.errorsAllFromValidation = errorsAllFromValidation;

var processApiError =
/*#__PURE__*/
function () {
  var _ref = (0, _asyncToGenerator2.default)(
  /*#__PURE__*/
  _regenerator.default.mark(function _callee(fetcherError) {
    var response, unprocessableEntityCode, _ref2, errors, validationErrorsArray, validationErrorsObject, validationError;

    return _regenerator.default.wrap(function _callee$(_context) {
      while (1) {
        switch (_context.prev = _context.next) {
          case 0:
            response = fetcherError.response;
            unprocessableEntityCode = 422;

            if (!(response && parseInt(response.status) === unprocessableEntityCode)) {
              _context.next = 15;
              break;
            }

            _context.next = 5;
            return response.json();

          case 5:
            _ref2 = _context.sent;
            errors = _ref2.errors;
            validationErrorsArray = (0, _flatten.default)(Object.values(errors)).filter(function (error) {
              return error.validation_error;
            });

            if (validationErrorsArray.length) {
              _context.next = 10;
              break;
            }

            throw fetcherError;

          case 10:
            validationErrorsObject = {};
            validationErrorsArray.forEach(function (error) {
              validationErrorsObject[error.input_id] = validationErrorsObject[error.input_id] || [];
              validationErrorsObject[error.input_id].push({
                type: 'error',
                text: validationTextForError(error.error_type)
              });
            });
            validationError = Object.assign(Object.create(Error.prototype), fetcherError);
            validationError.validationErrorsFromApi = validationErrorsObject;
            throw validationError;

          case 15:
            throw fetcherError;

          case 16:
          case "end":
            return _context.stop();
        }
      }
    }, _callee);
  }));

  return function processApiError(_x) {
    return _ref.apply(this, arguments);
  };
}();

exports.processApiError = processApiError;