"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.createQuizEntryRegrade = createQuizEntryRegrade;

var _regenerator = _interopRequireDefault(require("@babel/runtime/regenerator"));

var _asyncToGenerator2 = _interopRequireDefault(require("@babel/runtime/helpers/asyncToGenerator"));

var _quizCommon = require("@instructure/quiz-common");

var _modal = require("../../common/actions/modal");

var _Fetcher = _interopRequireDefault(require("../../common/util/Fetcher"));

var _alerts = require("../../common/actions/alerts");

var _helpers = require("../../common/api/helpers");

var _formatMessage = _interopRequireDefault(require("@instructure/quiz-i18n/lib/format-message"));

function createQuizEntryRegrade(quizId, payload) {
  var url = "/api/quizzes/".concat(quizId, "/quiz_entry_regrades");
  var params = {
    item_id: payload.itemId,
    quiz_entry_id: payload.quizEntryId,
    points_possible: payload.pointsPossible,
    score_reconciliation: payload.scoreReconciliation,
    scoring_algorithm: payload.scoringAlgorithm,
    scoring_data: payload.scoringData
  };
  var body = JSON.stringify({
    quiz_entry_regrade: params
  });
  return function (dispatch, getState) {
    var fetcher = new _Fetcher.default({
      cloneResponseForError: true,
      callType: _quizCommon.CREATE_QUIZ_ENTRY_REGRADE,
      onError: function onError(_ref) {
        var response = _ref.response;
        return (
          /*#__PURE__*/
          function () {
            var _ref2 = (0, _asyncToGenerator2.default)(
            /*#__PURE__*/
            _regenerator.default.mark(function _callee(dispatch) {
              var errMsg, _ref3, errors, showError, delayToAllowRerenderAndRefocus;

              return _regenerator.default.wrap(function _callee$(_context) {
                while (1) {
                  switch (_context.prev = _context.next) {
                    case 0:
                      errMsg = (0, _formatMessage.default)('Regrade did not run.');

                      if (!(response && response.status === 422)) {
                        _context.next = 12;
                        break;
                      }

                      _context.prev = 2;
                      _context.next = 5;
                      return response.json();

                    case 5:
                      _ref3 = _context.sent;
                      errors = _ref3.errors;

                      if ((0, _helpers.errorsAllFromValidation)(errors)) {
                        errMsg = (0, _formatMessage.default)('Regrade did not run due to invalid input data.');
                      }

                      _context.next = 12;
                      break;

                    case 10:
                      _context.prev = 10;
                      _context.t0 = _context["catch"](2);

                    case 12:
                      showError = function showError() {
                        return dispatch((0, _alerts.addError)(errMsg));
                      }; // The Header for QuizEntryEdit has a 200ms delay in componentDidMount before
                      // moving focus to its title.
                      // If we try to show the error banner immediately, VoiceOver will begin reading
                      // it, but get interupted part way through by the focus moving to the Header.
                      // We need a long enough delay here for the modal to close, the QuizEntryEdit
                      // header to get mounted, the delay to happen and the focus to move to the title.
                      // Please forgive me.


                      delayToAllowRerenderAndRefocus = 800;
                      setTimeout(showError, delayToAllowRerenderAndRefocus);

                    case 15:
                    case "end":
                      return _context.stop();
                  }
                }
              }, _callee, null, [[2, 10]]);
            }));

            return function (_x) {
              return _ref2.apply(this, arguments);
            };
          }()
        );
      }
    });
    var requestParams = {
      body: body // Although the fetcher has an onError method, it's specifically for dispatching
      // redux actions (e.g. to show notifications).
      // API validation error handling doesn't go through redux, so we catch the
      // fetcher error separately below and add the necessary formatted data to it

    };
    return fetcher.post(url, requestParams).then(function () {
      dispatch((0, _modal.closeModal)(_quizCommon.REGRADE_MODAL));
    }).catch(_helpers.processApiError);
  };
}